NaiveProverChannel

Struct NaiveProverChannel 

pub struct NaiveProverChannel<'a, F, Challenger_>
where F: Field, Challenger_: Challenger,
{ /* private fields */ }
A naive prover channel that writes full polynomial data to the transcript.

This channel wraps a ProverTranscript and provides oracle operations by writing the entire polynomial coefficients to the transcript. This is useful for testing protocols without the complexity of FRI/BaseFold.

Type Parameters

  • F: The field type
  • Challenger_: The Fiat-Shamir challenger

Implementations

Source

impl<'a, F, Challenger_> NaiveProverChannel<'a, F, Challenger_>
where F: Field, Challenger_: Challenger,

pub const fn new( transcript: &'a mut ProverTranscript<Challenger_>, oracle_specs: Vec<OracleSpec>, ) -> Self

Creates a new naive prover channel.

Arguments
  • transcript - The prover transcript for Fiat-Shamir (borrowed mutably)
  • oracle_specs - Specifications for each oracle to be committed
pub const fn transcript(&self) -> &ProverTranscript<Challenger_>

Returns a reference to the underlying transcript.

pub fn finish(self)

Consumes the channel, asserting all oracle specs have been consumed.